@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-text-1.1.0.0/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: text
-version: 0.11.3.1
-id: text-0.11.3.1-5af30448b2c3a30eee31b3ea9b549812
+version: 1.1.0.0
+id: text-1.1.0.0-72236c81391c0a9a303f37559690d8fe
 
 license: BSD3
 copyright: 2009-2011 Bryan O'\''Sullivan, 2008-2009 Tom Harper
@@ -37,57 +38,52 @@ description:
              non-standard encodings, text breaking, and locales), see
              the @text-icu@ package:
              <http://hackage.haskell.org/package/text-icu>
-             .
-             &#8212;&#8212; RELEASE NOTES &#8212;&#8212;
-             .
-             Changes in 0.11.2.0:
-             .
-             * String literals are now converted directly from the format in
-             which GHC stores them into '\''Text'\'', without an intermediate
-             transformation through '\''String'\'', and without inlining of
-             conversion code at each site where a string literal is declared.
-             .
 category: Data, Text
 author: Bryan O'\''Sullivan <bos@serpentine.com>
 pkgpath: devel/hs-text
 exposed: True
 exposed-modules: Data.Text Data.Text.Array Data.Text.Encoding
                  Data.Text.Encoding.Error Data.Text.Foreign Data.Text.IO
-                 Data.Text.Internal Data.Text.Lazy Data.Text.Lazy.Builder
-                 Data.Text.Lazy.Builder.Int Data.Text.Lazy.Builder.RealFloat
-                 Data.Text.Lazy.Encoding Data.Text.Lazy.IO Data.Text.Lazy.Internal
-                 Data.Text.Lazy.Read Data.Text.Read Data.Text.Unsafe
-hidden-modules: Data.Text.Encoding.Fusion
-                Data.Text.Encoding.Fusion.Common Data.Text.Encoding.Utf16
-                Data.Text.Encoding.Utf32 Data.Text.Encoding.Utf8 Data.Text.Fusion
-                Data.Text.Fusion.CaseMapping Data.Text.Fusion.Common
-                Data.Text.Fusion.Internal Data.Text.Fusion.Size
-                Data.Text.IO.Internal Data.Text.Lazy.Builder.Functions
-                Data.Text.Lazy.Builder.Int.Digits Data.Text.Lazy.Builder.Internal
-                Data.Text.Lazy.Builder.RealFloat.Functions
-                Data.Text.Lazy.Encoding.Fusion Data.Text.Lazy.Fusion
-                Data.Text.Lazy.Search Data.Text.Private Data.Text.Search
-                Data.Text.Unsafe.Base Data.Text.UnsafeChar Data.Text.UnsafeShift
-                Data.Text.Util
+                 Data.Text.Internal Data.Text.Internal.Builder
+                 Data.Text.Internal.Builder.Functions
+                 Data.Text.Internal.Builder.Int.Digits
+                 Data.Text.Internal.Builder.RealFloat.Functions
+                 Data.Text.Internal.Encoding.Fusion
+                 Data.Text.Internal.Encoding.Fusion.Common
+                 Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
+                 Data.Text.Internal.Encoding.Utf8 Data.Text.Internal.Functions
+                 Data.Text.Internal.Fusion Data.Text.Internal.Fusion.CaseMapping
+                 Data.Text.Internal.Fusion.Common Data.Text.Internal.Fusion.Size
+                 Data.Text.Internal.Fusion.Types Data.Text.Internal.IO
+                 Data.Text.Internal.Lazy Data.Text.Internal.Lazy.Encoding.Fusion
+                 Data.Text.Internal.Lazy.Fusion Data.Text.Internal.Lazy.Search
+                 Data.Text.Internal.Private Data.Text.Internal.Search
+                 Data.Text.Internal.Unsafe Data.Text.Internal.Unsafe.Char
+                 Data.Text.Internal.Unsafe.Shift Data.Text.Lazy
+                 Data.Text.Lazy.Builder Data.Text.Lazy.Builder.Int
+                 Data.Text.Lazy.Builder.RealFloat Data.Text.Lazy.Encoding
+                 Data.Text.Lazy.IO Data.Text.Lazy.Internal Data.Text.Lazy.Read
+                 Data.Text.Read Data.Text.Unsafe
+hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/text-0.11.3.1
-library-dirs: /usr/local/lib/ghc/text-0.11.3.1
-hs-libraries: HStext-0.11.3.1
+import-dirs: /usr/local/lib/ghc/text-1.1.0.0
+library-dirs: /usr/local/lib/ghc/text-1.1.0.0
+hs-libraries: HStext-1.1.0.0
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
-         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
-         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
-         deepseq-1.3.0.1-5cc4cd89bdc2e8f6db1833d95ec36926
-         ghc-prim-0.3.0.0-d5221a8c8a269b66ab9a07bdc23317dd
-         integer-gmp-0.5.0.0-2f15426f5b53fe4c6490832f9b20d8d7
+depends: array-0.5.0.0-470385a50d2b78598af85cfe9d988e1b
+         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
+         deepseq-1.3.0.2-63a1ab91b7017a28bb5d04cb1b5d2d02
+         ghc-prim-0.3.1.0-a24f9c14c632d75b683d0f93283aea37
+         integer-gmp-0.5.1.0-26579559b3647acf4f01d5edd9491a46
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-text-0.11.3.1/html/text.haddock
-haddock-html: /usr/local/share/doc/hs-text-0.11.3.1/html
+haddock-interfaces: /usr/local/share/doc/hs-text-1.1.0.0/html/text.haddock
+haddock-html: /usr/local/share/doc/hs-text-1.1.0.0/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
